{% load static %}

<link href="{% static 'django_superset_integration/css/django-superset-integration.css' %}" rel="stylesheet"/>

<button id="superset-fullscreen" class="{{ button_fullscreen_classes }}">
    Afficher en plein écran
</button>

<button id="superset-fullscreen-exit" class="{{ button_quit_fullscreen_classes }}">
    Quitter le mode plein écran
</button>

<div id="superset-integration">
</div>

<script src="{% static 'django_superset_integration/js/superset-embedded-sdk.js' %}"></script>
<script src="{% static 'django_superset_integration/js/get-guest-token.js' %}" defer data-dashboardid="{{ dashboard_id }}"></script>
<script src="{% static 'django_superset_integration/js/display-dashboard.js' %}" defer data-dashboardintegrationid="{{ dashboard_integration_id }}" data-supersetdomain="{{ superset_domain }}" data-iframeheight="{{ iframe_height }}"></script>
